#
# spec file for package linuxconsoletools
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           linuxconsoletools
Version:        1.8.1
Release:        1.3
Summary:        A set of utilities for joysticks
License:        GPL-2.0-or-later
Group:          Hardware/Joystick
URL:            http://sourceforge.net/projects/linuxconsole/
Source0:        http://sourceforge.net/projects/linuxconsole/files/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE 0001-fix-bashisms.patch
Patch0:         0001-fix-bashisms.patch
BuildRequires:  libSDL2-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(udev)
# moved in 13.2
Provides:       input-utils = 2007.06.22
Obsoletes:      input-utils < 2007.06.22

%description
This package contains the following utilities and associated
documentation:
* joystick utilities - calibrate and test joysticks and joypads

The following utilities are provided to calibrate and test joysticks:
* evdev-joystick - test & calibrate joysticks using evdev devices
* ffcfstress, ffmvforce, fftest - test force-feedback devices
* ffset - set force-feedback device parameters
* jscal - calibrate joystick devices, reconfigure the axes and buttons
* jscal-store, jscal-restore - store and retrieve joystick device settings as configured using jscal
* jstest - test joystick devices

%prep
%autosetup -p1

%build
make %{?_smp_mflags} \
    CFLAGS="%{optflags}" \
    PREFIX=%{_prefix} \
    SYSTEMD_SUPPORT=1

%install
make %{?_smp_mflags} \
    DESTDIR=%{buildroot} \
    PREFIX=%{_prefix} \
    install
# fix permissions
chmod 644 %{buildroot}%{_mandir}/man1/*
# Fix udev dirs
mkdir -p %{buildroot}%{_prefix}/lib/udev
mv %{buildroot}/lib/udev/js-set-enum-leds %{buildroot}%{_prefix}/lib/udev/js-set-enum-leds
mkdir -p %{buildroot}%{_udevrulesdir}
mv %{buildroot}/lib/udev/rules.d/80-stelladaptor-joystick.rules %{buildroot}%{_udevrulesdir}/80-stelladaptor-joystick.rules
rm %{buildroot}/%{_bindir}/inputattach \
   %{buildroot}/%{_mandir}/man1/inputattach.1

%files
%license COPYING
%doc NEWS README
%{_bindir}/evdev-joystick
%{_bindir}/ffcfstress
%{_bindir}/ffmvforce
%{_bindir}/ffset
%{_bindir}/fftest
%{_bindir}/jscal
%{_bindir}/jscal-restore
%{_bindir}/jscal-store
%{_bindir}/jstest
%{_mandir}/man1/ffcfstress.1%{ext_man}
%{_mandir}/man1/ffmvforce.1%{ext_man}
%{_mandir}/man1/ffset.1%{ext_man}
%{_mandir}/man1/fftest.1%{ext_man}
%{_mandir}/man1/jscal-restore.1%{ext_man}
%{_mandir}/man1/jscal-store.1%{ext_man}
%{_mandir}/man1/jscal.1%{ext_man}
%{_mandir}/man1/jstest.1%{ext_man}
%{_mandir}/man1/evdev-joystick.1%{ext_man}
%{_datadir}/joystick/
%{_prefix}/lib/udev/js-set-enum-leds
%{_udevrulesdir}/80-stelladaptor-joystick.rules

%changelog
* Mon Dec 26 2022 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.8.1
  * jscal can be given a specific button to use to confirm calibration
    at each step.
- update to 1.7.1
  * inputattach supports the Gunze protocol
- update to 1.7.0
  * The udev rules for Stelladaptor devices include more compatible devices
  * inputattach supports the FlySky FS-iA6B RC receiver, with kernel 5.4
    and later
  * ffmvforce now needs SDL2 and pkg-config (thanks to Stefan Brüns).
  * inputattach has a --crtscts/--no-crscts option to control CRTSCTS;
    it also supports up to four probe-able devices checked in sequence
  * js-set-enum-leds supports Wii controllers, XBox gamepads, and PS4
    Dualshock 4 gamepads
- removed patch 0001-Port-ffmvforce-to-SDL2-some-bugfixes.patch - merged in upstream
- added patch 0001-fix-bashisms.patch
* Wed Aug 19 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through the -mini flavors.
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Thu Aug  1 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 1.6.1
  * inputattach supports the RainShadow HDMI CEC dongle (this requires
    kernel 4.12 or later; thanks to Hans Verkuil).
- Port ffmvforce away from SDL 1.2, add
  0001-Port-ffmvforce-to-SDL2-some-bugfixes.patch
* Fri Jan 25 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- update to 1.6.0
  * inputattach supports the Pulse-Eight HDMI CEC dongle (this requires kernel 4.8 or later; thanks to Hans Verkuil <hverkuil@xs4all.nl>).
  * evdev-joystick can set the minimum and maximum axis values (thanks to Jon Sangster <jon@ertt.ca>).
  * The udev rules are installed without executable permissions.
  * The evdev-joystick manpage is installed along with the other manpages.
* Wed May 10 2017 sndirsch@suse.com
- no longer ship inputattach; we no longer support serial input
  devices (fate#323262)
* Tue Sep 27 2016 adam@mizerski.pl
- update to 1.5.1
  * Correctly install 80-stelladaptor-joystick.rules.
- update to 1.5.0
  * Add Stephen Anthony's evdev-joystick tool, with his agreement.
- set PREFIX for compilation too (bsc#1000895)
* Thu Feb 11 2016 mpluskal@suse.com
- Update to 1.4.9
  * inputattach supports a new mouseman4 mode for 4-button Logitech
    mice
  * inputattach supports EETI eGalaxTouch touchscreens
  * inputattach can provide a "ready" notification to systemd
  * js-set-enum-leds no longer uses hotplug.functions.
- Spec file cleanups and dependency updates
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 1.4.8
  * Set up PS3 controller LEDs correctly
  * inputattach supports Wacom IV tablets on kernels 3.17 and greater
* Tue Feb 18 2014 adam@mizerski.pl
- update to 1.4.7
  * Correctly handle newer versions of the Spaceball firwmare (thanks to
    Andrew Basterfield <abasterfield@gmail.com>). This fixes Debian
    [#298494].
- updated the comment in spec file about when the spit took place.
* Mon Jun  3 2013 adam@mizerski.pl
- new package (version 1.4.6)
